/*
    This file is part of Accountant.

    Accountant is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Accountant is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with Accountant.  If not, see <http://www.gnu.org/licenses/>.
 */
accountantApp

.factory("ScheduledOperations", ["$resource", function($resource) {
    return $resource(
        "/api/scheduled_operations/:id", {
            id: "@id"
        }
    );
}])

.controller(
    "SchedulerController", [
        "$scope", "$rootScope", "$routeParams", "notificationService", "ScheduledOperations",
        function($scope, $rootScope, $routeParams, notificationService, ScheduledOperations) {
    // Operations store and selection
    $scope.operations = [];

    $scope.categories = [];

    $scope.addOperation = function() {
        operation = new ScheduledOperations({});
        operation.account_id = $routeParams.accountId;
        $scope.operations.splice(0, 0, operation);
    };

    $scope.loadOperations = function(accountId) {
      // Clean up selected entry.
      $scope.selectedOperation = null;
      $scope.savedOperation = null;

      $scope.operations = ScheduledOperations.query({
          account: $routeParams.accountId
      });
    };

    // Save operation.
    $scope.saveOperation = function($data, $index) {
      var operation;

      if($data.$save) {
        operation = $data;
      } else {
        operation = $scope.operations[$index];
        operation = angular.merge(operation, $data);
      }

      return operation.$save().then(function(data) {
        notificationService.success("Operation #" + data.id + " saved.");
        return data;
      });
    };

    // Reload operation from server to cancel edition.
    $scope.cancelEditOperation = function(operation, rowform, $index) {
      if(!operation.id) {
        $scope.operations.splice($index, 1);
      } else {
        rowform.$cancel();
      }
    };

    /*
     * Delete a scheduled operation.
     */
    $scope.delete = function(operation, $index) {
      var id = operation.id;

      bootbox.confirm(
        "Voulez-vous supprimer l'operation planifiée \"" + operation.label + "\" ?",
        function(result) {
          if(result) {
            operation.$delete().then(function() {
              notificationService.success("Operation #" + id + " deleted.");

              // Remove account from array.
              $scope.operations.splice($index, 1);
            });
          }
        }
      );
    };

    // Load operations on controller initialization.
    $scope.loadOperations($routeParams.accountId);
}]);
